pub enum TaskKind {
BreakCycle {
cycle: Vec<String>,
},
ImplementSpec {
spec_id: String,
},
Custom {
description: String,
},
}Expand description
Kind of task that can be planned.
Variants are deliberately domain-neutral. Specialised variants for any given problem domain belong outside this crate.
Variants
BreakCycle
Break a circular dependency cycle in the task graph.
This is a generic graph operation, not coupled to any particular problem domain.
ImplementSpec
Implement a spec requirement.
Custom
Custom user-defined task.