TaskKind

Enum TaskKind 

pub enum TaskKind {
    BreakCycle {
        cycle: Vec<String>,
    },
    ImplementSpec {
        spec_id: String,
    },
    Custom {
        description: String,
    },
}
Kind of task that can be planned.

Variants are deliberately domain-neutral. Specialised variants for any given problem domain belong outside this crate.

Variants



BreakCycle

Break a circular dependency cycle in the task graph.

This is a generic graph operation, not coupled to any particular problem domain.

Fields

cycle: Vec<String>

Module identifiers (or generally, node ids) forming the cycle.



ImplementSpec

Implement a spec requirement.

Fields

spec_id: String

Opaque identifier of the specification to implement.



Custom

Custom user-defined task.

Fields

description: String

Free-form description of the work.